@@ -61,6 +61,7 @@ __all__ = (
     "OutboundCrossClusterSearchConnectionStatusTypeDef",
     "OutboundCrossClusterSearchConnectionTypeDef",
     "PackageDetailsTypeDef",
+    "PackageVersionHistoryTypeDef",
     "RecurringChargeTypeDef",
     "ReservedElasticsearchInstanceOfferingTypeDef",
     "ReservedElasticsearchInstanceTypeDef",
@@ -103,6 +104,7 @@ __all__ = (
     "DissociatePackageResponseTypeDef",
     "FilterTypeDef",
     "GetCompatibleElasticsearchVersionsResponseTypeDef",
+    "GetPackageVersionHistoryResponseTypeDef",
     "GetUpgradeHistoryResponseTypeDef",
     "GetUpgradeStatusResponseTypeDef",
     "ListDomainNamesResponseTypeDef",
@@ -117,6 +119,7 @@ __all__ = (
     "RejectInboundCrossClusterSearchConnectionResponseTypeDef",
     "StartElasticsearchServiceSoftwareUpdateResponseTypeDef",
     "UpdateElasticsearchDomainConfigResponseTypeDef",
+    "UpdatePackageResponseTypeDef",
     "UpgradeElasticsearchDomainResponseTypeDef",
     "VPCOptionsTypeDef",
 )
@@ -207,6 +210,7 @@ DomainPackageDetailsTypeDef = TypedDict(
         "DomainPackageStatus": Literal[
             "ASSOCIATING", "ASSOCIATION_FAILED", "ACTIVE", "DISSOCIATING", "DISSOCIATION_FAILED"
         ],
+        "PackageVersion": str,
         "ReferencePath": str,
         "ErrorDetails": "ErrorDetailsTypeDef",
     },
@@ -588,11 +592,19 @@ PackageDetailsTypeDef = TypedDict(
             "DELETE_FAILED",
         ],
         "CreatedAt": datetime,
+        "LastUpdatedAt": datetime,
+        "AvailablePackageVersion": str,
         "ErrorDetails": "ErrorDetailsTypeDef",
     },
     total=False,
 )
 
+PackageVersionHistoryTypeDef = TypedDict(
+    "PackageVersionHistoryTypeDef",
+    {"PackageVersion": str, "CommitMessage": str, "CreatedAt": datetime},
+    total=False,
+)
+
 RecurringChargeTypeDef = TypedDict(
     "RecurringChargeTypeDef",
     {"RecurringChargeAmount": float, "RecurringChargeFrequency": str},
@@ -1034,6 +1046,16 @@ GetCompatibleElasticsearchVersionsResponseTypeDef = TypedDict(
     total=False,
 )
 
+GetPackageVersionHistoryResponseTypeDef = TypedDict(
+    "GetPackageVersionHistoryResponseTypeDef",
+    {
+        "PackageID": str,
+        "PackageVersionHistoryList": List["PackageVersionHistoryTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
+)
+
 GetUpgradeHistoryResponseTypeDef = TypedDict(
     "GetUpgradeHistoryResponseTypeDef",
     {"UpgradeHistories": List["UpgradeHistoryTypeDef"], "NextToken": str},
@@ -1177,6 +1199,10 @@ UpdateElasticsearchDomainConfigResponseTypeDef = TypedDict(
     {"DomainConfig": "ElasticsearchDomainConfigTypeDef"},
 )
 
+UpdatePackageResponseTypeDef = TypedDict(
+    "UpdatePackageResponseTypeDef", {"PackageDetails": "PackageDetailsTypeDef"}, total=False
+)
+
 UpgradeElasticsearchDomainResponseTypeDef = TypedDict(
     "UpgradeElasticsearchDomainResponseTypeDef",
     {"DomainName": str, "TargetVersion": str, "PerformCheckOnly": bool},
